==> kubernetes-model-admissionregistration-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/authorization/v1beta1/SubjectAccessReviewSpecBuilder.java <==
package io.fabric8.kubernetes.api.model.authorization.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class SubjectAccessReviewSpecBuilder extends io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectAccessReviewSpecFluentImpl<io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectAccessReviewSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectAccessReviewSpec,io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectAccessReviewSpecBuilder>{
  public SubjectAccessReviewSpecBuilder() {
    this(false);
  }
  public SubjectAccessReviewSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new SubjectAccessReviewSpec(), validationEnabled);
  }
  public SubjectAccessReviewSpecBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectAccessReviewSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public SubjectAccessReviewSpecBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectAccessReviewSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new SubjectAccessReviewSpec(), validationEnabled);
  }
  public SubjectAccessReviewSpecBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectAccessReviewSpecFluent<?> fluent,io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectAccessReviewSpec instance) {
    this(fluent, instance, false);
  }
  public SubjectAccessReviewSpecBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectAccessReviewSpecFluent<?> fluent,io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectAccessReviewSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withExtra(instance.getExtra()); 
    fluent.withGroup(instance.getGroup()); 
    fluent.withNonResourceAttributes(instance.getNonResourceAttributes()); 
    fluent.withResourceAttributes(instance.getResourceAttributes()); 
    fluent.withUid(instance.getUid()); 
    fluent.withUser(instance.getUser()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public SubjectAccessReviewSpecBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectAccessReviewSpec instance) {
    this(instance,false);
  }
  public SubjectAccessReviewSpecBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectAccessReviewSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withExtra(instance.getExtra()); 
    this.withGroup(instance.getGroup()); 
    this.withNonResourceAttributes(instance.getNonResourceAttributes()); 
    this.withResourceAttributes(instance.getResourceAttributes()); 
    this.withUid(instance.getUid()); 
    this.withUser(instance.getUser()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectAccessReviewSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectAccessReviewSpec build() {
    SubjectAccessReviewSpec buildable = new SubjectAccessReviewSpec(fluent.getExtra(),fluent.getGroup(),fluent.getNonResourceAttributes(),fluent.getResourceAttributes(),fluent.getUid(),fluent.getUser());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SubjectAccessReviewSpecBuilder that = (SubjectAccessReviewSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-admissionregistration-6.6.0-sources.jar: io/fabric8/kubernetes/api/model/authorization/v1beta1/SubjectAccessReviewSpecBuilder.java <==
package io.fabric8.kubernetes.api.model.authorization.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class SubjectAccessReviewSpecBuilder extends SubjectAccessReviewSpecFluentImpl<SubjectAccessReviewSpecBuilder> implements VisitableBuilder<SubjectAccessReviewSpec,SubjectAccessReviewSpecBuilder>{
  public SubjectAccessReviewSpecBuilder() {
    this(false);
  }
  public SubjectAccessReviewSpecBuilder(Boolean validationEnabled) {
    this(new SubjectAccessReviewSpec(), validationEnabled);
  }
  public SubjectAccessReviewSpecBuilder(SubjectAccessReviewSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public SubjectAccessReviewSpecBuilder(SubjectAccessReviewSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new SubjectAccessReviewSpec(), validationEnabled);
  }
  public SubjectAccessReviewSpecBuilder(SubjectAccessReviewSpecFluent<?> fluent,SubjectAccessReviewSpec instance) {
    this(fluent, instance, false);
  }
  public SubjectAccessReviewSpecBuilder(SubjectAccessReviewSpecFluent<?> fluent,SubjectAccessReviewSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withExtra(instance.getExtra()); 
    fluent.withGroup(instance.getGroup()); 
    fluent.withNonResourceAttributes(instance.getNonResourceAttributes()); 
    fluent.withResourceAttributes(instance.getResourceAttributes()); 
    fluent.withUid(instance.getUid()); 
    fluent.withUser(instance.getUser()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public SubjectAccessReviewSpecBuilder(SubjectAccessReviewSpec instance) {
    this(instance,false);
  }
  public SubjectAccessReviewSpecBuilder(SubjectAccessReviewSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withExtra(instance.getExtra()); 
    this.withGroup(instance.getGroup()); 
    this.withNonResourceAttributes(instance.getNonResourceAttributes()); 
    this.withResourceAttributes(instance.getResourceAttributes()); 
    this.withUid(instance.getUid()); 
    this.withUser(instance.getUser()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  SubjectAccessReviewSpecFluent<?> fluent;
  Boolean validationEnabled;
  public SubjectAccessReviewSpec build() {
    SubjectAccessReviewSpec buildable = new SubjectAccessReviewSpec(fluent.getExtra(),fluent.getGroup(),fluent.getNonResourceAttributes(),fluent.getResourceAttributes(),fluent.getUid(),fluent.getUser());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
